summaryrefslogtreecommitdiff
path: root/TAO/tao/Invocation.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/tao/Invocation.h')
-rw-r--r--TAO/tao/Invocation.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/TAO/tao/Invocation.h b/TAO/tao/Invocation.h
index ef2ef23d30d..8a1f8658409 100644
--- a/TAO/tao/Invocation.h
+++ b/TAO/tao/Invocation.h
@@ -206,7 +206,7 @@ protected:
* Returns TAO_INVOKE_RESTART if the write call failed and the
* request must be re-attempted.
*
* @param is_synchronous If set invoke() does not return until the
* message is completely delivered to the underlying
* transport mechanism, or an error is detected.
*
@@ -214,7 +214,7 @@ protected:
* that the server closed the connection simply to release
* resources.
*/
- int invoke (CORBA::Boolean is_synchronous
+ int invoke (CORBA::Boolean write_semantics
ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
@@ -206,7 +206,7 @@ protected:
* request must be re-attempted.
*
- * @param is_synchronous If set invoke() does not return until the
+ * @param write_semantics If set invoke() does not return until the
* message is completely delivered to the underlying
* transport mechanism, or an error is detected.